@@ -659,7 +659,7 @@ STATICforIDL CDFstatus ReadAEDR64 VARPROTOARGs((vFILE *fp, OFF_T offset, ...));
 STATICforIDL CDFstatus ReadADRList64 PROTOARGs((vFILE *fp));
 STATICforIDL CDFstatus ReadAEDRList64 PROTOARGs((
   vFILE *fp, struct AEDRstructExt64 ***AEDRList, OFF_T AEDRHead,
-  Int32 MaxEntry
+  Int32 NumEntries, Int32 MaxEntry
 ));
 STATICforIDL CDFstatus ReadVDR64 VARPROTOARGs((
   struct CDFstruct *CDF, vFILE *fp, OFF_T offset, Logical zVar, ...
