@@ -22,6 +22,9 @@
 *                               in READONLYon mode.
 *   V3.2a 11-Apr-08, M Liu      Modified Read32s_64 and Read64s_64 to 
 *                               eliminate the potential buffer overflow.
+*   V3.2b 15-Sep-08, M Liu      Modified ReadAEDRList64 to pass in the number of
+*                               entries to set up the list, not just the last
+*                               entry number. 
 *
 ******************************************************************************/
 
@@ -267,7 +270,7 @@ va_dcl
 #endif
 {
   long read_only_mode;
-  long i;
+  int i;
   va_list ap; CDFstatus pStatus = CDF_OK;
 #if defined(STDARG)
   va_start (ap, offset);
@@ -1821,10 +1824,12 @@ STATICforIDL CDFstatus ReadADRList64 (vFILE *fp)
       ***********************************************************************/
       pStatus = ReadAEDRList64(fp, &(fp->ADRList64[i]->grAEDRList64),
                                fp->ADRList64[i]->AgrEDRhead, 
+                               fp->ADRList64[i]->NgrEntries,
                                fp->ADRList64[i]->MAXgrEntry);
       if (pStatus != CDF_OK) return pStatus;
       pStatus = ReadAEDRList64(fp, &(fp->ADRList64[i]->zAEDRList64),
                                fp->ADRList64[i]->AzEDRhead, 
+                               fp->ADRList64[i]->NzEntries,
                                fp->ADRList64[i]->MAXzEntry);
       if (pStatus != CDF_OK) return pStatus;
   };
@@ -1839,14 +1844,15 @@ STATICforIDL CDFstatus ReadADRList64 (vFILE *fp)
 * pair), the list entry is NULL.
 ******************************************************************************/
 STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp, 
-                                         struct AEDRstructExt64 ***AEDRList, 
-                                         OFF_T AEDRHead, 
-                                         Int32 MaxEntry)
+                                       struct AEDRstructExt64 ***AEDRList, 
+                                       OFF_T AEDRHead, 
+                                       Int32 NumEntries,
+                                       Int32 MaxEntry)
 {
   CDFstatus pStatus = CDF_OK;
   OFF_T NxtAEDR = AEDRHead;
   struct AEDRstructExt64 *TempAEDR;
-  Int32 LastAEDRNum = -1;
+  Int32 iEntries;
   Int32 i;
   OFF_T temp;
   /**************************************************************************
@@ -1867,11 +1873,12 @@ STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp,
   {
       (*AEDRList)[i] = NULL;
   };
+  iEntries = 0;
   /***************************************************************************
   * Allocate memory for each AEDR, read each AEDR, and assign them to the list
   * by entry number.
   ***************************************************************************/
-  while (NxtAEDR != 0 && LastAEDRNum != MaxEntry)            
+  while (NxtAEDR != 0 && iEntries != NumEntries)            
   {
       TempAEDR = cdf_AllocateMemory(sizeof(struct AEDRstructExt64), NULL);
       if (TempAEDR == NULL) return BAD_MALLOC;
@@ -1896,7 +1903,7 @@ STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp,
       TempAEDR->Value = cdf_AllocateMemory(TempAEDR->ValueSize, NULL);
       if (TempAEDR->Value == NULL) return BAD_MALLOC;
       if (!READv64(TempAEDR->Value,TempAEDR->ValueSize,1,fp)) return CRE;
-      LastAEDRNum = TempAEDR->AEDR.Num;
+      ++iEntries;
       (*AEDRList)[TempAEDR->AEDR.Num] = TempAEDR;
   };
   return pStatus;
