@@ -87,11 +87,11 @@ Logical qopError = FALSE;
 FILE *fp;
 QOP *qop;
 static char *validQuals[] = {
-  "dump", "output", "format", "noformat", "vars", "about", 
+  "dump", "output", "format", "noformat", "vars", "about", "noheader", 
   NULL 
 };
 static int optRequired[] = {
-  TRUE, TRUE, FALSE, FALSE, TRUE, FALSE, 
+  TRUE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, 
   0
 };
 int numValidDumps = 3;
@@ -149,6 +149,12 @@ switch (argC) {
       cdf_FreeMemory (qop, FatalError);
       return TRUE;
     }
+    /**************************************************************************
+    * Check for `noheader' qualifier.
+    **************************************************************************/
+    if (qop->qualEntered[NOHEADERqual]) {
+      noheader = TRUE;
+    }
     /************************************************************************
     * Check for `output' qualifier.
     ************************************************************************/
@@ -204,15 +210,17 @@ switch (argC) {
   /****************************************************************************
   * Display information.
   ****************************************************************************/
-  WriteOut (stdout, "Dumping cdf from \"");
-  WriteOut (stdout, CDFpath);
-  if (!EndsWithIgCase(CDFpath, ".cdf"))
-    WriteOut (stdout, ".cdf");
-  if (!NULstring(outputFile)) { 
-    WriteOut (stdout, "\"  to  \"");
-    WriteOut (stdout, outputFile);
+  if (!noheader) {
+    WriteOut (stdout, "Dumping cdf from \"");
+    WriteOut (stdout, CDFpath);
+    if (!EndsWithIgCase(CDFpath, ".cdf"))
+      WriteOut (stdout, ".cdf");
+    if (!NULstring(outputFile)) { 
+      WriteOut (stdout, "\"  to  \"");
+      WriteOut (stdout, outputFile);
+    }
+    WriteOut (stdout, "\"...\n");
   }
-  WriteOut (stdout, "\"...\n");
 
   if (!strcmp(outputFile, CDFpath)) {
       DisplayError ("Output file name is identical to source CDF file.");
